@@ -23,7 +23,7 @@ import re, os
 
 
 # The current version of rdiff-backup
-version = "0.11.3"
+version = "0.11.4"
 
 # If this is set, use this value in seconds as the current time
 # instead of reading it from the clock.
@@ -148,6 +148,10 @@ ssh_compression = 1
 # If true, print statistics after successful backup
 print_statistics = None
 
+# Controls whether file_statistics file is written in
+# rdiff-backup-data dir.  These can sometimes take up a lot of space.
+file_statistics = 1
+
 # On the writer connection, the following will be set to the mirror
 # Select iterator.
 select_mirror = None
