@@ -25,7 +25,7 @@ import Globals, log, static, TempFile, rpath
 
 def get_signature(rp):
 	"""Take signature of rpin file and return in file object"""
-	log.Log("Getting signature of %s" % rp.path, 7)
+	log.Log("Getting signature of %s" % rp.get_indexpath(), 7)
 	return librsync.SigFile(rp.open("rb"))
 
 def get_delta_sigfileobj(sig_fileobj, rp_new):
@@ -56,7 +56,7 @@ def write_via_tempfile(fp, rp):
 	"""Write fileobj fp to rp by writing to tempfile and renaming"""
 	tf = TempFile.new(rp)
 	tf.write_from_fileobj(fp)
-	tf.rename(rp)
+	rpath.rename(tf, rp)
 
 def patch_local(rp_basis, rp_delta, outrp = None, delta_compressed = None):
 	"""Patch routine that must be run locally, writes to outrp
