@@ -20,7 +20,7 @@
 """Manage logging, displaying and recording messages with required verbosity"""
 
 import time, sys, traceback, types
-import Globals
+import Globals, static, re
 
 
 class LoggerError(Exception): pass
@@ -58,9 +58,9 @@ class Logger:
 
 		"""
 		assert not self.log_file_open
-		rpath.conn.Log.open_logfile_local(rpath)
+		rpath.conn.log.Log.open_logfile_local(rpath)
 		for conn in Globals.connections:
-			conn.Log.open_logfile_allconn(rpath.conn)
+			conn.log.Log.open_logfile_allconn(rpath.conn)
 
 	def open_logfile_allconn(self, log_file_conn):
 		"""Run on all connections to signal log file is open"""
@@ -81,8 +81,8 @@ class Logger:
 		"""Close logfile and inform all connections"""
 		if self.log_file_open:
 			for conn in Globals.connections:
-				conn.Log.close_logfile_allconn()
-			self.log_file_conn.Log.close_logfile_local()
+				conn.log.Log.close_logfile_allconn()
+			self.log_file_conn.log.Log.close_logfile_local()
 
 	def close_logfile_allconn(self):
 		"""Run on every connection"""
@@ -125,7 +125,7 @@ class Logger:
 		if self.log_file_open:
 			if self.log_file_local:
 				self.logfp.write(self.format(message, self.verbosity))
-			else: self.log_file_conn.Log.log_to_file(message)
+			else: self.log_file_conn.log.Log.log_to_file(message)
 
 	def log_to_term(self, message, verbosity):
 		"""Write message to stdout/stderr"""
@@ -150,8 +150,12 @@ class Logger:
 		self.log_to_term("%s %s (%d): %s" %
 						 (conn_str, direction, req_num, result_repr), 9)
 
-	def FatalError(self, message):
-		self("Fatal Error: " + message, 1)
+	def FatalError(self, message, no_fatal_message = 0):
+		"""Log a fatal error and exit"""
+		assert no_fatal_message == 0 or no_fatal_message == 1
+		if no_fatal_message: prefix_string = ""
+		else: prefix_string = "Fatal Error: "
+		self(prefix_string + message, 1)
 		import Main
 		Main.cleanup()
 		sys.exit(1)
@@ -183,3 +187,83 @@ class Logger:
 
 Log = Logger()
 
+
+class ErrorLog:
+	"""Log each recoverable error in error_log file
+
+	There are three types of recoverable errors:  ListError, which
+	happens trying to list a directory or stat a file, UpdateError,
+	which happen when trying to update a changed file, and
+	SpecialFileError, which happen when a special file cannot be
+	created.  See the error policy file for more info.
+
+	"""
+	_log_fileobj = None
+	_log_inc_rp = None
+	def open(cls, time_string, compress = 1):
+		"""Open the error log, prepare for writing"""
+		if not Globals.isbackup_writer:
+			return Globals.backup_writer.log.ErrorLog.open(time_string,
+														   compress)
+		assert not cls._log_fileobj and not cls._log_inc_rp, "log already open"
+		assert Globals.isbackup_writer
+		if compress: typestr = 'data.gz'
+		else: typestr = 'data'
+		cls._log_inc_rp = Globals.rbdir.append("error_log.%s.%s" %
+											   (time_string, typestr))
+		assert not cls._log_inc_rp.lstat(), ("""Error file %s already exists.
+
+This is probably caused by your attempting to run two backups simultaneously
+or within one second of each other.  Wait a second and try again.""" %
+											 (cls._log_inc_rp.path,))
+		cls._log_fileobj = cls._log_inc_rp.open("wb", compress = compress)
+
+	def isopen(cls):
+		"""True if the error log file is currently open"""
+		if Globals.isbackup_writer or not Globals.backup_writer:
+			return cls._log_fileobj is not None
+		else: return Globals.backup_writer.log.ErrorLog.isopen()
+
+	def write(cls, error_type, rp, exc):
+		"""Add line to log file indicating error exc with file rp"""
+		if not Globals.isbackup_writer:
+			return Globals.backup_writer.log.ErrorLog.write(error_type,
+															rp, exc)
+		s = cls.get_log_string(error_type, rp, exc)
+		Log(s, 2)
+		if Globals.null_separator: s += "\0"
+		else:
+			s = re.sub("\n", " ", s)
+			s += "\n"
+		cls._log_fileobj.write(s)
+
+	def get_indexpath(cls, obj):
+		"""Return filename for logging.  rp is a rpath, string, or tuple"""
+		try: return obj.get_indexpath()
+		except AttributeError:
+			if type(obj) is types.TupleType: return "/".join(obj)
+			else: return str(obj)
+
+	def write_if_open(cls, error_type, rp, exc):
+		"""Call cls.write(...) if error log open, only log otherwise"""
+		if not Globals.isbackup_writer:
+			return Globals.backup_writer.log.ErrorLog.write_if_open(
+				error_type, rp, exc)
+		if cls.isopen(): cls.write(error_type, rp, exc)
+		else: Log(cls.get_log_string(error_type, rp, exc), 2)
+
+	def get_log_string(cls, error_type, rp, exc):
+		"""Return log string to put in error log"""
+		assert (error_type == "ListError" or error_type == "UpdateError" or
+				error_type == "SpecialFileError"), "Unknown type "+error_type
+		return "%s %s %s" % (error_type, cls.get_indexpath(rp), str(exc))
+
+	def close(cls):
+		"""Close the error log file"""
+		if not Globals.isbackup_writer:
+			return Globals.backup_writer.log.ErrorLog.close()
+		assert not cls._log_fileobj.close()
+		cls._log_fileobj = cls._log_inc_rp = None
+
+static.MakeClass(ErrorLog)
+
