@@ -440,8 +440,8 @@ class RORPath:
 
 	def getnumlinks(self):
 		"""Number of places inode is linked to"""
-		try: return self.data['nlink']
-		except KeyError: return 1
+		if self.data.has_key('nlink'): return self.data['nlink']
+		else: return 1
 
 	def readlink(self):
 		"""Wrapper around os.readlink()"""
@@ -644,7 +644,7 @@ class RPath(RORPath):
 	def setmtime(self, modtime):
 		"""Set only modtime (access time to present)"""
 		log.Log(lambda: "Setting time of %s to %d" % (self.path, modtime), 7)
-		self.conn.os.utime(self.path, (time.time(), modtime))
+		self.conn.os.utime(self.path, (long(time.time()), modtime))
 		self.data['mtime'] = modtime
 
 	def chown(self, uid, gid):
