@@ -26,8 +26,7 @@ documentation on what this code does can be found on the man page.
 
 from __future__ import generators
 import re
-from log import Log
-import FilenameMapping, robust, rpath, Globals
+import FilenameMapping, robust, rpath, Globals, log
 
 
 class SelectError(Exception):
@@ -80,21 +79,14 @@ class Select:
 	# This re should not match normal filenames, but usually just globs
 	glob_re = re.compile("(.*[*?[]|ignorecase\\:)", re.I | re.S)
 
-	def __init__(self, rootrp, quoted_filenames = None):
-		"""Select initializer.  rpath is the root directory
-
-		When files have quoted characters in them, quoted_filenames
-		should be true.  Then RPath's index will be the unquoted
-		version.
-
-		"""
+	def __init__(self, rootrp):
+		"""Select initializer.  rpath is the root directory"""
 		assert isinstance(rootrp, rpath.RPath)
 		self.selection_functions = []
 		self.rpath = rootrp
 		self.prefix = self.rpath.path
-		self.quoting_on = Globals.quoting_enabled and quoted_filenames
 
-	def set_iter(self, iterate_parents = None, sel_func = None):
+	def set_iter(self, sel_func = None):
 		"""Initialize more variables, get ready to iterate
 
 		Selection function sel_func is called on each rpath and is
@@ -103,24 +95,16 @@ class Select:
 		"""
 		if not sel_func: sel_func = self.Select
 		self.rpath.setdata() # this may have changed since Select init
-		if self.quoting_on:
-			self.iter = self.Iterate(self.rpath, self.Iterate, sel_func)
-		else: self.iter = self.Iterate_fast(self.rpath, sel_func)
-
-		# only iterate parents if we are not starting from beginning
+		self.iter = self.Iterate_fast(self.rpath, sel_func)
 		self.next = self.iter.next
 		self.__iter__ = lambda: self
 		return self
 
 	def Iterate_fast(self, rpath, sel_func):
-		"""Like Iterate, but don't recur, saving time
-
-		Only handles standard case (quoting off, starting from
-		beginning).
-
-		"""
+		"""Like Iterate, but don't recur, saving time"""
 		def error_handler(exc, filename):
-			Log("Error initializing file %s/%s" % (rpath.path, filename), 2)
+			log.ErrorLog.write_if_open("ListError",
+									   rpath.index + (filename,), exc)
 			return None
 
 		def diryield(rpath):
@@ -131,7 +115,7 @@ class Select:
 			and should be included iff something inside is included.
 
 			"""
-			for filename in robust.listrp(rpath):
+			for filename in self.listdir(rpath):
 				new_rpath = robust.check_common_error(error_handler,
 										rpath.append, (filename,))
 				if new_rpath:
@@ -188,23 +172,28 @@ class Select:
 				for rp in iid: yield rp
 		else: assert 0, "Invalid selection result %s" % (str(s),)
 
+	def listdir(self, dir_rp):
+		"""List directory rpath with error logging"""
+		def error_handler(exc):
+			log.ErrorLog.write_if_open("ListError", dir_rp, exc)
+			return []
+		dir_listing = robust.check_common_error(error_handler, dir_rp.listdir)
+		dir_listing.sort()
+		return dir_listing
+
 	def iterate_in_dir(self, rpath, rec_func, sel_func):
 		"""Iterate the rpaths in directory rpath."""
 		def error_handler(exc, filename):
-			Log("Error initializing file %s/%s" % (rpath.path, filename), 2)
+			log.ErrorLog.write_if_open("ListError",
+									   rpath.index + (filename,), exc)
 			return None
 
-		if self.quoting_on:
-			for subdir in get_quoted_dir_children(rpath):
-				for rp in rec_func(subdir, rec_func, sel_func):
+		for filename in self.listdir(rpath):
+			new_rp = robust.check_common_error(
+				error_handler, rpath.append, [filename])
+			if new_rp:
+				for rp in rec_func(new_rp, rec_func, sel_func):
 					yield rp
-		else:
-			for filename in robust.listrp(rpath):
-				new_rp = robust.check_common_error(
-					error_handler, rpath.append, [filename])
-				if new_rp:
-					for rp in rec_func(new_rp, rec_func, sel_func):
-						yield rp
 
 	def Select(self, rp):
 		"""Run through the selection functions and return dominant val 0/1/2"""
@@ -270,7 +259,7 @@ class Select:
 	def parse_catch_error(self, exc):
 		"""Deal with selection error exc"""
 		if isinstance(exc, FilePrefixError):
-			Log.FatalError(
+			log.Log.FatalError(
 """Fatal Error: The file specification
 '    %s'
 cannot match any files in the base directory
@@ -279,8 +268,8 @@ Useful file specifications begin with the base directory or some
 pattern (such as '**') which matches the base directory.""" %
 			(exc, self.prefix))
 		elif isinstance(e, GlobbingError):
-			Log.FatalError("Fatal Error while processing expression\n"
-						   "%s" % exc)
+			log.Log.FatalError("Fatal Error while processing expression\n"
+							   "%s" % exc)
 		else: raise
 
 	def parse_rbdir_exclude(self):
@@ -292,7 +281,7 @@ pattern (such as '**') which matches the base directory.""" %
 		"""Exit with error if last selection function isn't an exclude"""
 		if (self.selection_functions and
 			not self.selection_functions[-1].exclude):
-			Log.FatalError(
+			log.Log.FatalError(
 """Last selection expression:
     %s
 only specifies that files be included.  Because the default is to
@@ -315,10 +304,10 @@ probably isn't what you meant.""" %
 		filelist_name is just a string used for logging.
 
 		"""
-		Log("Reading filelist %s" % filelist_name, 4)
+		log.Log("Reading filelist %s" % filelist_name, 4)
 		tuple_list, something_excluded = \
 					self.filelist_read(filelist_fp, inc_default, filelist_name)
-		Log("Sorting filelist %s" % filelist_name, 4)
+		log.Log("Sorting filelist %s" % filelist_name, 4)
 		tuple_list.sort()
 		i = [0] # We have to put index in list because of stupid scoping rules
 
@@ -343,11 +332,11 @@ probably isn't what you meant.""" %
 			"""Warn if prefix is incorrect"""
 			prefix_warnings[0] += 1
 			if prefix_warnings[0] < 6:
-				Log("Warning: file specification '%s' in filelist %s\n"
-					"doesn't start with correct prefix %s.  Ignoring." %
-					(exc, filelist_name, self.prefix), 2)
+				log.Log("Warning: file specification '%s' in filelist %s\n"
+						"doesn't start with correct prefix %s.  Ignoring." %
+						(exc, filelist_name, self.prefix), 2)
 				if prefix_warnings[0] == 5:
-					Log("Future prefix errors will not be logged.", 2)
+					log.Log("Future prefix errors will not be logged.", 2)
 
 		something_excluded, tuple_list = None, []
 		separator = Globals.null_separator and "\0" or "\n"
@@ -360,7 +349,7 @@ probably isn't what you meant.""" %
 			tuple_list.append(tuple)
 			if not tuple[1]: something_excluded = 1
 		if filelist_fp.close():
-			Log("Error closing filelist %s" % filelist_name, 2)
+			log.Log("Error closing filelist %s" % filelist_name, 2)
 		return (tuple_list, something_excluded)
 
 	def filelist_parse_line(self, line, include):
@@ -418,7 +407,7 @@ probably isn't what you meant.""" %
 		See the man page on --[include/exclude]-globbing-filelist
 
 		"""
-		Log("Reading globbing filelist %s" % list_name, 4)
+		log.Log("Reading globbing filelist %s" % list_name, 4)
 		separator = Globals.null_separator and "\0" or "\n"
 		for line in filelist_fp.read().split(separator):
 			if not line: continue # skip blanks
@@ -442,7 +431,7 @@ probably isn't what you meant.""" %
 		assert include == 0 or include == 1
 		try: regexp = re.compile(regexp_string)
 		except:
-			Log("Error compiling regular expression %s" % regexp_string, 1)
+			log.Log("Error compiling regular expression %s" % regexp_string, 1)
 			raise
 		
 		def sel_func(rp):
@@ -456,8 +445,8 @@ probably isn't what you meant.""" %
 	def devfiles_get_sf(self, include):
 		"""Return a selection function matching all dev files"""
 		if self.selection_functions:
-			Log("Warning: exclude-device-files is not the first "
-				"selector.\nThis may not be what you intended", 3)
+			log.Log("Warning: exclude-device-files is not the first "
+					"selector.\nThis may not be what you intended", 3)
 		def sel_func(rp):
 			if rp.isdev(): return include
 			else: return None
@@ -468,8 +457,8 @@ probably isn't what you meant.""" %
 	def special_get_sf(self, include):
 		"""Return sel function matching sockets, symlinks, sockets, devs"""
 		if self.selection_functions:
-			Log("Warning: exclude-special-files is not the first "
-				"selector.\nThis may not be what you intended", 3)
+			log.Log("Warning: exclude-special-files is not the first "
+					"selector.\nThis may not be what you intended", 3)
 		def sel_func(rp):
 			if rp.issym() or rp.issock() or rp.isfifo() or rp.isdev():
 				return include
@@ -617,22 +606,4 @@ probably isn't what you meant.""" %
 		return res
 
 
-def get_quoted_dir_children(rpath):
-	"""For rpath directory, return list of quoted children in dir
-
-	This used to be in FilenameMapping, but was moved because it
-	depends on the robust.listrp routine.
-
-	"""
-	if not rpath.isdir(): return []
-	dir_pairs = [(FilenameMapping.unquote(filename), filename)
-				 for filename in robust.listrp(rpath)]
-	dir_pairs.sort() # sort by real index, not quoted part
-	child_list = []
-	for unquoted, filename in dir_pairs:
-		childrp = rpath.append(unquoted)
-		childrp.quote_path()
-		child_list.append(childrp)
-	return child_list
-
 
